@@ -130,9 +130,10 @@ class Weather:
 
 class Storage:
     def __init__(self):
-        self.id = None
+        self.pki = None
         self.image = None
-        self.record_id = None
+        self.meta = None
+        self.fk_record_id = None
 
     def _b64_to_image(self, b64: np.array):
         bytes_array = base64.b64decode(b64.encode())
@@ -146,13 +147,15 @@ class Storage:
         return np.array(image)
 
     def from_json(self, data):
-        if 'id' in data:
-            self.id = data['id']
+        if 'pki_uuid' in data:
+            self.pki = data['pki_uuid']
         if 'base64_bytes_array' in data:
             # converts to image on load
             self.image = self._b64_to_image(data['base64_bytes_array'])
-        if 'record_id' in data:
-            self.record_id = data['record_id']
+        if 'meta' in data:
+            self.meta = data['meta']
+        if 'fk_record_id' in data:
+            self.fk_record_id = data['fk_record_id']
 
 
 class FramesManager:
